@@ -298,6 +298,8 @@ struct ec_backend_op_stubs liberasurecode_rs_vand_op_stubs = {
     .RECONSTRUCT                = liberasurecode_rs_vand_reconstruct,
     .ELEMENTSIZE                = liberasurecode_rs_vand_element_size,
     .ISCOMPATIBLEWITH           = liberasurecode_rs_vand_is_compatible_with,
+    .GETMETADATASIZE            = get_backend_metadata_size_zero,
+    .GETENCODEOFFSET            = get_encode_offset_zero,
 };
 
 struct ec_backend_common backend_liberasurecode_rs_vand = {
@@ -306,7 +308,6 @@ struct ec_backend_common backend_liberasurecode_rs_vand = {
     .soname                     = LIBERASURECODE_RS_VAND_SO_NAME,
     .soversion                  = LIBERASURECODE_RS_VAND_LIB_VER_STR,
     .ops                        = &liberasurecode_rs_vand_op_stubs,
-    .backend_metadata_size      = 0,
     .ec_backend_version         = _VERSION(LIBERASURECODE_RS_VAND_LIB_MAJOR,
                                            LIBERASURECODE_RS_VAND_LIB_MINOR,
                                            LIBERASURECODE_RS_VAND_LIB_REV),
